==> gspiceui-v0.9.99.tar.gz: gspiceui-v0.9.99/src/gnucap/commands/CmdGnuCapGEN.hpp <==
//*****************************************************************************
//                               CmdGnuCapGEN.hpp                             *
//                              ------------------                            *
// Description : This class contains values associated with the GNU-Cap       *
//               GENERATOR command. It inherits from the class CmdBase.       *
// Started     : 11/03/2008                                                   *
// Last Update : 16/04/2010                                                   *
// Copyright   : (C) 2008 by M.S.Waters                                       *
// Email       : M.Waters@bom.gov.au                                          *
//*****************************************************************************

//*****************************************************************************
//                                                                            *
//    This program is free software; you can redistribute it and/or modify    *
//    it under the terms of the GNU General Public License as published by    *
//    the Free Software Foundation; either version 2 of the License, or       *
//    (at your option) any later version.                                     *
//                                                                            *
//*****************************************************************************

#ifndef CMDGCPGEN_HPP
#define CMDGCPGEN_HPP

// System Includes

#include <iostream>
#include <climits>

// wxWidgets Includes

#include <wx/wx.h>
#include <wx/tokenzr.h>

// Application Includes

#include "base/CmdBase.hpp"
#include "utility/ConvertType.hpp"
#include "netlist/CpntNgsIndSrc.hpp"

struct CpntNgsIndSrc;

// Local Macro and/or Constant Declarations

#define  GCP_AMPLITUDE   wxT("1.0")
#define  GCP_OFFSET      wxT("0.0")

#define  GCP_SINFREQ     wxT("0.0")
#define  GCP_SINPHASE    wxT("0.0")

#define  GCP_PULINITIAL  wxT("0.0")
#define  GCP_PULMIN      wxT("0.0")
#define  GCP_PULMAX      wxT("0.0")
#define  GCP_PULDELAY    wxT("0.0m")
#define  GCP_PULRISE     wxT("0.0m")
#define  GCP_PULWIDTH    wxT("0.0m")
#define  GCP_PULFALL     wxT("0.0m")
#define  GCP_PULPERIOD   wxT("0.0m")

//*****************************************************************************

struct CmdGnuCapGEN : public CmdBase
{
  private :

    virtual  bool  bValidate( void );

  public :

    // Overall source characteristics
    wxString  m_osAmplitude;
    wxString  m_osOffset;

    // Sinusoidal source characteristics
    wxString  m_osSinFreq;
    wxString  m_osSinPhase;

    // Pulse source characteristics
    wxString  m_osPulInitial;
    wxString  m_osPulMin;
    wxString  m_osPulMax;
    wxString  m_osPulDelay;
    wxString  m_osPulRise;
    wxString  m_osPulWidth;
    wxString  m_osPulFall;
    wxString  m_osPulPeriod;

              CmdGnuCapGEN( void );
    virtual  ~CmdGnuCapGEN( );

    virtual  bool  bClear( void );

    virtual  bool  bParse ( void );
    virtual  bool  bFormat( void );

    CmdGnuCapGEN & operator = ( const CpntNgsIndSrc & roIndSrc );

    void  Print( const wxString & rosPrefix=wxT("  ") );
};

//*****************************************************************************

#endif // CMDGCPGEN_HPP

==> gspiceui-v1.0.00.tar.gz: gspiceui-v1.0.00/src/gnucap/commands/CmdGnuCapGEN.hpp <==
//*****************************************************************************
//                               CmdGnuCapGEN.hpp                             *
//                              ------------------                            *
// Description : This class contains values associated with the GNU-Cap       *
//               GENERATOR command. It inherits from the class CmdBase.       *
// Started     : 11/03/2008                                                   *
// Last Update : 24/12/2010                                                   *
// Copyright   : (C) 2008 by M.S.Waters                                       *
// Email       : M.Waters@bom.gov.au                                          *
//*****************************************************************************

//*****************************************************************************
//                                                                            *
//    This program is free software; you can redistribute it and/or modify    *
//    it under the terms of the GNU General Public License as published by    *
//    the Free Software Foundation; either version 2 of the License, or       *
//    (at your option) any later version.                                     *
//                                                                            *
//*****************************************************************************

#ifndef CMDGCPGEN_HPP
#define CMDGCPGEN_HPP

// System Includes

#include <iostream>
#include <climits>

// wxWidgets Includes

#include <wx/wx.h>
#include <wx/tokenzr.h>

// Application Includes

#include "base/CmdBase.hpp"
#include "utility/ConvertType.hpp"
#include "netlist/CpntNgsIndSrc.hpp"

struct CpntNgsIndSrc;

// Local Macro and/or Constant Declarations

#define  GCP_AMPLITUDE   wxT("1.0")
#define  GCP_OFFSET      wxT("0.0")

#define  GCP_SINFREQ     wxT("0.0")
#define  GCP_SINPHASE    wxT("0.0")

#define  GCP_PULINITIAL  wxT("0.0")
#define  GCP_PULMIN      wxT("0.0")
#define  GCP_PULMAX      wxT("0.0")
#define  GCP_PULDELAY    wxT("0.0m")
#define  GCP_PULRISE     wxT("0.0m")
#define  GCP_PULWIDTH    wxT("0.0m")
#define  GCP_PULFALL     wxT("0.0m")
#define  GCP_PULPERIOD   wxT("0.0m")

//*****************************************************************************

struct CmdGnuCapGEN : public CmdBase
{
  private :

    virtual  bool  bValidate( void );

  public :

    // Overall source characteristics
    wxString  m_osAmplitude;
    wxString  m_osOffset;

    // Sinusoidal source characteristics
    wxString  m_osSinFreq;
    wxString  m_osSinPhase;

    // Pulse source characteristics
    wxString  m_osPulInitial;
    wxString  m_osPulMin;
    wxString  m_osPulMax;
    wxString  m_osPulDelay;
    wxString  m_osPulRise;
    wxString  m_osPulWidth;
    wxString  m_osPulFall;
    wxString  m_osPulPeriod;

              CmdGnuCapGEN( void );
    virtual  ~CmdGnuCapGEN( );

    virtual  bool  bSetDefaults( void );

    virtual  bool  bParse ( void );
    virtual  bool  bFormat( void );

    CmdGnuCapGEN & operator = ( const CpntNgsIndSrc & roIndSrc );

    void  Print( const wxString & rosPrefix=wxT("  ") );
};

//*****************************************************************************

#endif // CMDGCPGEN_HPP
